@@ -1,5 +1,7 @@
 """
-Main interface for secretsmanager service client paginators.
+Type annotations for secretsmanager service client paginators.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html)
 
 Usage::
 
@@ -32,7 +34,7 @@ __all__ = ("ListSecretsPaginator",)
 
 class ListSecretsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
     """
 
     def paginate(
@@ -42,5 +44,6 @@ class ListSecretsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSecretsResponseTypeDef]:
         """
-        [ListSecrets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.62/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/paginators.html#listsecretspaginator)
         """
